@@ -13,7 +13,7 @@ from jade.jobs.cluster import Cluster
 from jade.jobs.job_configuration_factory import create_config_from_file
 from jade.jobs.results_aggregator import ResultsAggregator
 from jade.jobs.job_submitter import JobSubmitter
-from jade.loggers import setup_logging
+from jade.loggers import setup_logging, setup_event_logging
 from jade.result import ResultsSummary
 from jade.utils.utils import rotate_filenames
 
@@ -54,14 +54,12 @@ def resubmit_jobs(output, failed, missing, rotate_logs, verbose):
     if rotate_logs:
         rotate_filenames(output, ".log")
 
+    event_file = os.path.join(output, "submit_jobs_events.log")
+    setup_event_logging(event_file, mode="a")
     filename = os.path.join(output, "submit_jobs.log")
     level = logging.DEBUG if verbose else logging.INFO
     setup_logging(__name__, filename, file_level=level, console_level=level, mode="a")
 
-    event_file = os.path.join(output, "submit_jobs_events.log")
-    # This effectively means no console logging.
-    setup_logging("event", event_file, console_level=logging.ERROR, file_level=logging.INFO)
-
     cluster, promoted = Cluster.deserialize(
         output,
         try_promote_to_submitter=True,
@@ -100,8 +98,9 @@ def _get_jobs_to_resubmit(cluster, output, failed, missing):
     results = ResultsSummary(output)
     jobs_to_resubmit = []
     if failed:
-        jobs_to_resubmit += results.get_canceled_results()
-        jobs_to_resubmit += results.get_failed_results()
+        res = results.get_results_by_type()
+        jobs_to_resubmit += res["canceled"]
+        jobs_to_resubmit += res["failed"]
     if missing:
         jobs_to_resubmit += results.get_missing_jobs(cluster.iter_jobs())
 
@@ -119,9 +118,12 @@ def _update_with_blocking_jobs(jobs_to_resubmit, output):
     for i in range(max_iter):
         first = len(jobs_to_resubmit)
         for job in config.iter_jobs():
-            blocking_jobs = job.get_blocking_jobs().intersection(jobs_to_resubmit)
-            updated_blocking_jobs_by_name[job.name] = blocking_jobs
-            if blocking_jobs:
+            blocking_jobs = job.get_blocking_jobs()
+            if not blocking_jobs:
+                continue
+            intersecting_jobs = blocking_jobs.intersection(jobs_to_resubmit)
+            if intersecting_jobs:
+                updated_blocking_jobs_by_name[job.name] = intersecting_jobs
                 jobs_to_resubmit.add(job.name)
         num_added = len(jobs_to_resubmit) - first
         if num_added == 0:
