@@ -5,6 +5,7 @@ import os
 import shutil
 import time
 import uuid
+from pathlib import Path
 
 from jade.common import JOBS_OUTPUT_DIR, OUTPUT_DIR, get_temp_results_filename
 from jade.enums import Status, ResourceMonitorType
@@ -15,7 +16,7 @@ from jade.jobs.async_cli_command import AsyncCliCommand
 from jade.jobs.job_manager_base import JobManagerBase
 from jade.jobs.job_queue import JobQueue
 from jade.models import JobState
-from jade.loggers import setup_logging
+from jade.loggers import close_event_logging
 from jade.resource_monitor import ResourceMonitorAggregator, ResourceMonitorLogger
 from jade.utils.timing_utils import timed_info
 
@@ -33,16 +34,14 @@ class JobRunner(JobManagerBase):
         batch_id=0,
     ):
         super(JobRunner, self).__init__(config_file, output)
-        cluster, _ = Cluster.deserialize(output)
-        self._check_jobs(cluster)
-        self._handle_submission_groups_after_deserialize(cluster)
+        self._handle_submission_groups()
         group = self.config.get_default_submission_group()
         config = group.submitter_params.hpc_config
         self._intf = HpcManager.create_hpc_interface(config)
         self._node_id = self._intf.get_node_id()
         self._intf_type = config.hpc_type
         self._batch_id = batch_id
-        self._event_file = os.path.join(
+        self._event_filename = os.path.join(
             output,
             f"run_jobs_batch_{batch_id}_{self._node_id}_events.log",
         )
@@ -50,20 +49,9 @@ class JobRunner(JobManagerBase):
 
         logger.debug("Constructed JobRunner output=%s batch=%s", output, batch_id)
 
-    def _check_jobs(self, cluster: Cluster):
-        if cluster.job_status is None:
-            # This is true in local mode and these checks are not relevant.
-            return
-
-        # Perform a sanity check. If all jobs aren't "submitted" then something went wrong.
-        submitted_jobs = {job.name for job in cluster.iter_jobs(state=JobState.SUBMITTED)}
-        error_jobs = []
-        for job in self._config.iter_jobs():
-            if job.name not in submitted_jobs:
-                error_jobs.append(job.name)
-        if error_jobs:
-            logger.error("Jobs were not in the submitted state: %s", " ".join(error_jobs))
-            assert not error_jobs, f"number of jobs not in submitted state = {len(error_jobs)}"
+    @property
+    def event_filename(self):
+        return self._event_filename
 
     @property
     def node_id(self):
@@ -77,11 +65,13 @@ class JobRunner(JobManagerBase):
         return self._node_id
 
     @timed_info
-    def run_jobs(self, verbose=False, num_processes=None):
+    def run_jobs(self, distributed_submitter=True, verbose=False, num_processes=None):
         """Run the jobs.
 
         Parameters
         ----------
+        distributed_submitter : bool
+            If True, make cluster updates.
         verbose : bool
             If True, enable debug logging.
         num_processes : int
@@ -96,11 +86,6 @@ class JobRunner(JobManagerBase):
         scratch_dir = self._create_local_scratch()
         are_inputs_local = self._intf_type == HpcType.LOCAL
 
-        # Not sure exactly why, but this needs to come after run_jobs.py has initialized logging.
-        self._event_logger = setup_logging(
-            "event", self._event_file, console_level=logging.ERROR, file_level=logging.INFO
-        )
-
         try:
             config_file = self._config.serialize_for_execution(scratch_dir, are_inputs_local)
 
@@ -109,7 +94,7 @@ class JobRunner(JobManagerBase):
             logger.info("Completed %s jobs", len(jobs))
         finally:
             shutil.rmtree(scratch_dir)
-            if not are_inputs_local:
+            if distributed_submitter and are_inputs_local:
                 self._complete_hpc_job()
 
         return result
@@ -227,9 +212,8 @@ class JobRunner(JobManagerBase):
     def _aggregate_events(self):
         # Aggregate all job events.log files into this node's log file so
         # that the we can more quickly make events.json later.
-        for handler in self._event_logger.handlers:
-            handler.close()
-        with open(self._event_file, "a") as f_out:
+        close_event_logging()
+        with open(self._event_filename, "a") as f_out:
             for job in self._config.iter_jobs():
                 job_file = os.path.join(self._output, JOBS_OUTPUT_DIR, job.name, "events.log")
                 if not os.path.exists(job_file):
@@ -239,4 +223,4 @@ class JobRunner(JobManagerBase):
                     for line in f_in:
                         f_out.write(line)
                 os.remove(job_file)
-                logger.debug("Moved contents of %s to %s", job_file, self._event_file)
+                logger.debug("Moved contents of %s to %s", job_file, self._event_filename)
