@@ -17,7 +17,7 @@ logger = logging.getLogger(__name__)
 class ResultsAggregator:
     """Synchronizes updates to the results file across jobs on one system."""
 
-    def __init__(self, path, timeout=60, delimiter=","):
+    def __init__(self, path, timeout=300, delimiter=","):
         """
         Constructs ResultsAggregator.
 
@@ -153,7 +153,7 @@ class ResultsAggregator:
         """
         results = [x for x in self.get_results() if x.name not in jobs_to_resubmit]
         self._write_results(results)
-        logger.info("Cleared %s results from %s", len(results), self._filename)
+        logger.info("Cleared %s results from %s", len(results), self._processed_filename)
 
     def clear_unsuccessful_results(self):
         """Remove failed and canceled results from the results file."""
